"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * https://www.w3.org/TR/WCAG20/#relativeluminancedef
 */
function calculateRelativeLuminance(value) {
    var sR = value.red / 255;
    var sG = value.green / 255;
    var sB = value.blue / 255;
    var R = sR <= 0.03928 ? (sR / 12.92) : (Math.pow(((sR + 0.055) / 1.055), 2.4));
    var G = sG <= 0.03928 ? (sG / 12.92) : (Math.pow(((sG + 0.055) / 1.055), 2.4));
    var B = sB <= 0.03928 ? (sB / 12.92) : (Math.pow(((sB + 0.055) / 1.055), 2.4));
    return 0.2126 * R + 0.7152 * G + 0.0722 * B;
}
function contrastInfo(c1, c2) {
    var L1 = calculateRelativeLuminance(c1);
    var L2 = calculateRelativeLuminance(c2);
    var ratio = (Math.max(L1, L2) + 0.05) / (Math.min(L1, L2) + 0.05);
    return {
        ratio: parseFloat(ratio.toFixed(2)),
        isAA: ratio >= 4.5,
        isAALarge: ratio >= 3,
        isAAA: ratio >= 7,
        isAAALarge: ratio >= 4.5,
        isUIAA: ratio >= 3
    };
}
exports.contrastInfo = contrastInfo;
;
//# sourceMappingURL=contrastInfo.js.map